import pytest
from mysqld_integration_test.log import logger
from mysqld_integration_test.exceptions import InvalidLogLevel


@pytest.mark.log_test
def test_log_levelset_noexception():
    logger.setlevel('INFO')
    assert True


@pytest.mark.log_test
def test_log_levelset_info_noexception():
    logger.setlevel('INFO')
    assert True


@pytest.mark.log_test
def test_log_levelset_debug_noexception():
    logger.setlevel('DEBUG')
    assert True


@pytest.mark.log_test
def test_log_levelset_error_noexception():
    logger.setlevel('ERROR')
    assert True


@pytest.mark.log_test
def test_log_levelset_warn_noexception():
    logger.setlevel('WARN')
    assert True


@pytest.mark.log_test
def test_log_levelset_fail():
    with pytest.raises(InvalidLogLevel):
        logger.setlevel('FAKE')
    assert True


@pytest.mark.log_test
def test_log_debug_noexception():
    logger.debug("test")
    assert True


@pytest.mark.log_test
def test_log_info_noexception():
    logger.info("test")
    assert True


@pytest.mark.log_test
def test_log_error_noexception():
    logger.error("test")
    assert True


@pytest.mark.log_test
def test_log_success_noexception():
    logger.success("test")
    assert True



import logging
from mysqld_integration_test.exceptions import InvalidLogLevel

COLOR_OKBLUE = '\033[94m'
COLOR_OKGREEN = '\033[92m'
COLOR_FAIL = '\033[91m'
COLOR_ENDC = '\033[0m'


class _Log():
    def __init__(self):
        logging.debug("magic")
        self.logger = logging.getLogger('mysqld-integration-test')
        self.logger.setLevel(logging.ERROR)

    def debug(self, msg):
        if self.logger:
            self.logger.debug(msg)

    def info(self, msg):
        if self.logger:
            self.logger.info(_colored(msg, COLOR_OKBLUE))

    def error(self, msg):
        if self.logger:
            self.logger.error(_colored(msg, COLOR_FAIL))

    def success(self, msg):
        if self.logger:
            self.logger.info(_colored(msg, COLOR_OKGREEN))

    def setlevel(self, log_level):
        if log_level == "INFO":
            self.logger.setLevel(logging.INFO)
        elif log_level == "DEBUG":
            self.logger.setLevel(logging.DEBUG)
        elif log_level == 'ERROR':
            self.logger.setLevel(logging.ERROR)
        elif log_level == 'WARN':
            self.logger.setLevel(logging.WARN)
        else:
            raise InvalidLogLevel


def _colored(msg, color):
    return f"{color}{msg}{COLOR_ENDC}"


logger = _Log()



import pytest
from mysqld_integration_test import Mysqld
import mysql.connector


@pytest.fixture
def mysqld_connect(autouse=True):
    mysqld = Mysqld()
    return mysqld.run()


def execute_query(mysqld, query):
    cnx = mysql.connector.connect(user=mysqld.username,
                                  password=mysqld.password,
                                  host=mysqld.host,
                                  port=mysqld.port, database='test')
    cursor = cnx.cursor()
    cursor.execute(query)
    cnx.commit()
    cursor.close()
    cnx.close()


def select_query(mysqld, query):
    cnx = mysql.connector.connect(user=mysqld.username,
                                  password=mysqld.password,
                                  host=mysqld.host,
                                  port=mysqld.port, database='test')
    cursor = cnx.cursor()
    cursor.execute(query)
    for _result in cursor:
        result = _result
    cursor.close()
    cnx.close()

    return result[0]


# This test makes sure things come up end to end
@pytest.mark.integration_test
def test_mysqld_endtoend(mysqld_connect):
    assert mysqld_connect.host == '127.0.0.1'


@pytest.mark.integration_test
def test_mysqld_create_table(mysqld_connect):
    execute_query(mysqld_connect,
                  'CREATE TABLE pytest_test (id int4 not null auto_increment, sometext text, primary key(id))')
    assert True


@pytest.mark.integration_test
def test_mysql_insert_into_table(mysqld_connect):
    execute_query(mysqld_connect,
                  'CREATE TABLE pytest_test (id int4 not null auto_increment, sometext text, primary key(id))')
    execute_query(mysqld_connect,
                  "INSERT INTO pytest_test (sometext) VALUES ('this is some text')")
    assert True


@pytest.mark.integration_test
def test_mysql_select_from_table(mysqld_connect):
    execute_query(mysqld_connect,
                  'CREATE TABLE pytest_test (id int4 not null auto_increment, sometext text, primary key(id))')
    execute_query(mysqld_connect,
                  "INSERT INTO pytest_test (sometext) VALUES ('this is some text')")
    select_id = select_query(mysqld_connect, "SELECT id FROM pytest_test")

    assert select_id == 1



from mysqld_integration_test import Mysqld
import pytest


@pytest.mark.skip
@pytest.mark.integration_test
@pytest.mark.integration_mysql_test
def test_mysqld_run_mysql():
    mysqld = Mysqld(mysqld_binary='tests/data/binaries/mysql/mysqld')
    instance = mysqld.run()
    assert instance.username == 'root'
